.. _trojanvision.attacks.backdoor.normal:

normal
================

.. currentmodule:: trojanvision.attacks

.. autoclass:: BadNet
    :members:

.. autoclass:: TrojanNN
    :members:

.. autoclass:: IMC
    :members:

.. autoclass:: LatentBackdoor
    :members:

.. autoclass:: TrojanNet
    :members:
